@@ -12,18 +12,21 @@ sub init {
     my $data  = Acme::MetaSyntactic->load_data($class);
     no strict 'refs';
 
+    my $sep = ${"$class\::Separator"} ||= '/';
+    my $tail = qr/$sep?[^$sep]*$/;
+
     # compute all categories
     my @categories = ( [ $data->{names}, '' ] );
     while ( my ( $h, $k ) = @{ shift @categories or []} ) {
         if ( ref $h eq 'HASH' ) {
             push @categories,
-                map { [ $h->{$_}, ( $k ? "$k/$_" : $_ ) ] } keys %$h;
+                map { [ $h->{$_}, ( $k ? "$k$sep$_" : $_ ) ] } keys %$h;
         }
         else {    # leaf
             my @items = split /\s+/, $h;
             while ($k) {
                 push @{ ${"$class\::MultiList"}{$k} }, @items;
-                $k =~ s!/?[^/]*$!!;
+                $k =~ s!$tail!!;
             }
         }
     }
@@ -80,7 +83,16 @@ sub new {
         if $self->{category} ne ':all'
         && !exists ${"$class\::MultiList"}{ $self->{category} };
 
+    $self->_compute_base();
+    return $self;
+}
+
+sub _compute_base {
+    my ($self) = @_;
+    my $class = ref $self;
+
     # compute the base list for this category
+    no strict 'refs';
     my %seen;
     $self->{base} = [
         grep { !$seen{$_}++ }
@@ -89,8 +101,7 @@ sub new {
         ? ( keys %{"$class\::MultiList"} )
         : ( $self->{category} )
     ];
-
-    return $self;
+    return;
 }
 
 sub category { $_[0]->{category} }
